﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace DependencyInjectionExample.DiConstructor
{
    //interface
    public interface INofificationAction
    {
        void ActOnNotification(string message);
    }

    //showMessage implementation
    class ShowMessage : INofificationAction
    {
        public void ActOnNotification(string message)
        {
            MessageBox.Show(message);
        }
    }

    //writeMessageToFile implementation
    class WriteMessageToFile : INofificationAction
    {
        public void ActOnNotification(string message)
        {
            string _exePath = System.IO.Path.GetDirectoryName(System.Reflection.Assembly.GetEntryAssembly().Location);
            string _file = _exePath + "\\helloWorld.txt";
            try
            {
                TextWriter tw = new StreamWriter(_file);

                // write a line of text to the file
                tw.WriteLine("test");

                // close the stream
                tw.Close();
            }
            catch
            {
                MessageBox.Show("Unable to write file to: " + _file);
            }
            finally
            {
                MessageBox.Show("Mesage was successfully writen to: " + _file);
            }
        }
    }

    class DoTheMessageIoC
    {
        private INofificationAction _actOnMessage = null;

        public DoTheMessageIoC(INofificationAction concreteImplementation)
        {
            this._actOnMessage = concreteImplementation;
        }

        public void Notify(object o)
        {
            _actOnMessage.ActOnNotification("Hello world!");
        }

    }
}